@@ -22,6 +22,16 @@
 
 #include "AbacusP.h"
 
+#ifdef HAVE_GETTEXT
+#include <stdio.h>
+#include <stdlib.h>
+#include <libintl.h>
+#include <locale.h>
+#define _(STRING) gettext(STRING)
+#else
+#define _(STRING) STRING
+#endif
+
 #define CHAR_TO_DIGIT(c) ((c >= 'A') ? c - 'A' + 10 : c - '0')
 #define DIGIT_TO_CHAR(d) ((d >= 10) ? (char) ('A' + d - 10) : (char) ('0' + d))
 #define IS_DIGIT(c) ((c >= '0' && c <= '9') || (c >= 'A' && c <= 'J'))
@@ -1337,6 +1347,7 @@ showHighlightRails(AbacusWidget w, int aux)
 }
 
 /* Tell about what is going to happen */
+/* extra space at end is to get rid of [] bug */
 static Boolean pendingUpdate(AbacusWidget w, char * buffer,
 	int line, int aux, int position, int base, int bottomNumber)
 {
@@ -1379,7 +1390,7 @@ static Boolean pendingUpdate(AbacusWidget w, char * buffer,
 		}
 		done = False;
 	}
-	(void) strcat(buffer, ".");
+	(void) strcat(buffer, ". ");
 	drawLineText(w, buffer, line);
 	return done;
 }
@@ -2022,7 +2033,7 @@ static void teachStepRoot(AbacusWidget w)
 				} else {
 					w->abacus.carryStep++;
 				}
-				(void) sprintf(buffer3, "Current answer (divide by %d): %s",
+				(void) sprintf(buffer3, "Current answer (divide by %d): %s ",
 					root, w->abacus.bString);
 				drawLineText(w, buffer3, 2);
 			} else {
@@ -2040,13 +2051,13 @@ static void teachStepRoot(AbacusWidget w)
 					drawLineText(w, buffer3, 2);
 					showHighlightRails(w, 1);
 				} else {
-					(void) sprintf(buffer3, "Current answer (divide by %d): %s",
+					(void) sprintf(buffer3, "Current answer (divide by %d): %s ",
 						root, w->abacus.bString);
 					drawLineText(w, buffer3, 2);
 				}
 			}
 		} else {
-			(void) sprintf(buffer3, "Current answer (divide by %d): %s",
+			(void) sprintf(buffer3, "Current answer (divide by %d): %s ",
 				root, w->abacus.bString);
 			drawLineText(w, buffer3, 2);
 			if (w->abacus.carry[w->abacus.state] != 0) {
@@ -2231,6 +2242,13 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 	int bottomNumber = w->abacus.decks[BOTTOM].number;
 	double a, b;
 
+#ifdef HAVE_GETTEXT
+	setlocale(LC_ALL, "");
+	/*bindtextdomain("AbacusT", getenv("PWD"));*/
+	bindtextdomain("AbacusT", "/usr/share/locale/");
+	textdomain("AbacusT");
+#endif
+
 #ifdef TEST
 	if (aux == 0) {
 #if 0
@@ -2345,7 +2363,7 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 			decimalSafe(w->abacus.bString);
 			addSafe(w->abacus.aString, w->abacus.bString);
 			(void) strcpy(w->abacus.rString, w->abacus.aString);
-			(void) sprintf(buffer3, "Current answer: %s",
+			(void) sprintf(buffer3, "Current answer: %s  ",
 				w->abacus.rString);
 			drawLineText(w, buffer3, 2);
 			w->abacus.step++;
@@ -2380,7 +2398,7 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 			decimalSafe(w->abacus.aString);
 			decimalSafe(w->abacus.bString);
 			(void) sprintf(w->abacus.rString, "0.");
-			(void) sprintf(buffer3, "Current answer: %s",
+			(void) sprintf(buffer3, "Current answer: %s  ",
 				w->abacus.rString);
 			drawLineText(w, buffer3, 2);
 			w->abacus.step++;
@@ -2423,7 +2441,7 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 			decimalSafe(w->abacus.bString);
 			(void) strcpy(w->abacus.rString, w->abacus.aString);
 			(void) sprintf(w->abacus.sString, "0.");
-			(void) sprintf(buffer3, "Current answer: %s",
+			(void) sprintf(buffer3, "Current answer: %s  ",
 				w->abacus.sString);
 			drawLineText(w, buffer3, 2);
 			w->abacus.step++;
@@ -2455,7 +2473,7 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 			drawLineText(w, buffer1, 0);
 			(void) strcpy(w->abacus.rString, w->abacus.aString);
 			(void) sprintf(w->abacus.sString, "0.");
-			(void) sprintf(buffer3, "Current answer: %s",
+			(void) sprintf(buffer3, "Current answer: %s  ",
 				w->abacus.sString);
 			drawLineText(w, buffer3, 2);
 			w->abacus.step++;
@@ -2665,16 +2683,22 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 			contractStringBuffer(w->abacus.rString);
 			if (w->abacus.op == 'v' || w->abacus.op == 'u') {
 				contractStringBuffer(w->abacus.sString);
-				(void) sprintf(buffer3, "Final answer: %s",
+				(void) sprintf(buffer3,
+					"%s %s",
+					_("Final answer:"),
 					w->abacus.sString);
 				showHighlightRails(w, 1);
 			} else if (w->abacus.op == '/') {
 				contractStringBuffer(w->abacus.sString);
-				(void) sprintf(buffer3, "Final answer: %s",
+				(void) sprintf(buffer3,
+					"%s %s",
+					_("Final answer:"),
 					w->abacus.sString);
 				showHighlightRails(w, 2);
 			} else {
-				(void) sprintf(buffer3, "Final answer: %s",
+				(void) sprintf(buffer3,
+					"%s %s",
+					_("Final answer:"),
 					w->abacus.rString);
 				showHighlightRails(w, 0);
 			}
@@ -2726,7 +2750,7 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 					w->abacus.lower, w->abacus.upper);
 				w->abacus.reg = -1;
 				contractStringBuffer(w->abacus.sString);
-				(void) sprintf(buffer3, "Current answer: %s",
+				(void) sprintf(buffer3, "Current answer: %s  ",
 					w->abacus.sString);
 				drawLineText(w, buffer3, 2);
 				return;
@@ -2757,7 +2781,7 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 					w->abacus.lower, w->abacus.upper);
 				w->abacus.reg = -1;
 				contractStringBuffer(w->abacus.sString);
-				(void) sprintf(buffer3, "Current answer: %s",
+				(void) sprintf(buffer3, "Current answer: %s  ",
 					w->abacus.sString);
 				drawLineText(w, buffer3, 2);
 				return;
@@ -2794,16 +2818,22 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 			w->abacus.step = 0;
 			if (w->abacus.op == 'v' || w->abacus.op == 'u') {
 				contractStringBuffer(w->abacus.sString);
-				(void) sprintf(buffer3, "Final answer: %s",
+				(void) sprintf(buffer3,
+					"%s %s",
+					_("Final answer:"),
 					w->abacus.sString);
 				showHighlightRails(w, 1);
 			} else if (w->abacus.op == '/') {
 				contractStringBuffer(w->abacus.sString);
-				(void) sprintf(buffer3, "Final answer: %s",
+				(void) sprintf(buffer3,
+					"%s %s",
+					_("Final answer:"),
 					w->abacus.sString);
 				showHighlightRails(w, 2);
 			} else {
-				(void) sprintf(buffer3, "Final answer: %s",
+				(void) sprintf(buffer3,
+					"%s %s",
+					_("Final answer:"),
 					w->abacus.rString);
 				showHighlightRails(w, 0);
 			}
@@ -2812,10 +2842,10 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 			if (w->abacus.op == '/' ||
 					w->abacus.op == 'v' || w->abacus.op == 'u') {
 				contractStringBuffer(w->abacus.sString);
-				(void) sprintf(buffer3, "Current answer: %s",
+				(void) sprintf(buffer3, "Current answer: %s  ",
 					w->abacus.sString);
 			} else {
-				(void) sprintf(buffer3, "Current answer: %s",
+				(void) sprintf(buffer3, "Current answer: %s  ",
 					w->abacus.rString);
 			}
 			drawLineText(w, buffer3, 2);
